# Generated by Django 4.2.20 on 2025-03-24 17:14

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name="DynamicField",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "name",
                    models.CharField(
                        db_comment="A unique identifier for the field inside a form.",
                        help_text="The name of the field.",
                        max_length=255,
                        verbose_name="Field Name",
                    ),
                ),
                (
                    "label",
                    models.CharField(
                        blank=True,
                        db_comment="User-friendly label for the field.",
                        help_text="The display label for this field (defaults to name if blank).",
                        max_length=255,
                        null=True,
                        verbose_name="Display Label",
                    ),
                ),
                (
                    "is_required",
                    models.BooleanField(
                        db_comment="If True, this field must be filled when submitting the form.",
                        default=False,
                        help_text="Whether this field is required.",
                        verbose_name="Required Field",
                    ),
                ),
                (
                    "choices",
                    models.JSONField(
                        blank=True,
                        db_comment="A JSON field storing dropdown choices.",
                        help_text="Applicable only for dropdown fields, stores the choices available.",
                        null=True,
                        verbose_name="Field Choices",
                    ),
                ),
                (
                    "default_value",
                    models.JSONField(
                        blank=True,
                        db_comment="The default value to prefill the field.",
                        help_text="Default value for this field, stored as JSON.",
                        null=True,
                        verbose_name="Default Value",
                    ),
                ),
                (
                    "validation_rules",
                    models.JSONField(
                        blank=True,
                        db_comment="JSON storing validation constraints.",
                        help_text="Optional validation rules (e.g., min_length, max_value, custom_validation).",
                        null=True,
                        verbose_name="Validation Rules",
                    ),
                ),
                (
                    "order",
                    models.PositiveIntegerField(
                        db_comment="Sorting order for field display.",
                        default=0,
                        help_text="Order in which this field appears in the form.",
                        verbose_name="Display Order",
                    ),
                ),
            ],
            options={
                "verbose_name": "Dynamic Field",
                "verbose_name_plural": "Dynamic Fields",
                "db_table": "dynamic_form_fields",
                "ordering": ["form", "order"],
            },
        ),
        migrations.CreateModel(
            name="DynamicForm",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "name",
                    models.CharField(
                        db_comment="A unique name for identifying the form.",
                        db_index=True,
                        help_text="The name of the form.",
                        max_length=255,
                        unique=True,
                        verbose_name="Form Name",
                    ),
                ),
                (
                    "description",
                    models.TextField(
                        blank=True,
                        db_comment="A short description about the form's purpose.",
                        help_text="Optional description of the form.",
                        null=True,
                        verbose_name="Description",
                    ),
                ),
                (
                    "is_active",
                    models.BooleanField(
                        db_comment="Controls if the form is available for use.",
                        default=True,
                        help_text="Whether this form is currently active and accepting submissions.",
                        verbose_name="Active",
                    ),
                ),
                (
                    "created_at",
                    models.DateTimeField(
                        auto_now_add=True,
                        db_comment="The date and time when the form was first created.",
                        help_text="Timestamp when the form was created.",
                        verbose_name="Creation Date",
                    ),
                ),
                (
                    "updated_at",
                    models.DateTimeField(
                        auto_now=True,
                        db_comment="The date and time of the last modification.",
                        help_text="Timestamp when the form was last updated.",
                        verbose_name="Last Updated",
                    ),
                ),
            ],
            options={
                "verbose_name": "Dynamic Form",
                "verbose_name_plural": "Dynamic Forms",
                "db_table": "dynamic_forms",
                "ordering": ["name"],
            },
        ),
        migrations.CreateModel(
            name="FieldType",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "name",
                    models.CharField(
                        db_comment="Unique slug-like name for the field type, used as a key in forms.",
                        help_text="A short, unique identifier for this field type (e.g., 'text', 'number').",
                        max_length=20,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "label",
                    models.CharField(
                        db_comment="User-friendly label for the field type (e.g., 'Text Field').",
                        help_text="The human-readable name of this field type, displayed to users.",
                        max_length=255,
                        verbose_name="Display Label",
                    ),
                ),
                (
                    "description",
                    models.TextField(
                        blank=True,
                        db_comment="Detailed explanation of the field type, useful for documentation.",
                        help_text="An optional description of this field type’s purpose or behavior.",
                        null=True,
                        verbose_name="Description",
                    ),
                ),
                (
                    "created_at",
                    models.DateTimeField(
                        auto_now_add=True,
                        db_comment="The date and time when this field type was first added.",
                        help_text="Timestamp when this field type was created.",
                        verbose_name="Creation Date",
                    ),
                ),
                (
                    "is_active",
                    models.BooleanField(
                        db_comment="Controls if the field type can be selected for new fields.",
                        default=True,
                        help_text="Whether this field type is currently available for use in forms.",
                        verbose_name="Active",
                    ),
                ),
            ],
            options={
                "verbose_name": "Field Type",
                "verbose_name_plural": "Field Types",
                "ordering": ["name"],
            },
        ),
        migrations.CreateModel(
            name="FormSubmission",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "submitted_data",
                    models.JSONField(
                        db_comment="Stores user responses in a JSON format.",
                        help_text="The data submitted by the user.",
                        verbose_name="Submission Data",
                    ),
                ),
                (
                    "submitted_at",
                    models.DateTimeField(
                        auto_now_add=True,
                        db_comment="The date and time when this form was submitted.",
                        help_text="Timestamp when the submission was made.",
                        verbose_name="Submission Time",
                    ),
                ),
                (
                    "form",
                    models.ForeignKey(
                        db_comment="A foreign key linking this submission to a dynamic form.",
                        help_text="The form to which this submission belongs.",
                        on_delete=django.db.models.deletion.CASCADE,
                        to="dynamic_form.dynamicform",
                        verbose_name="Submitted Form",
                    ),
                ),
                (
                    "user",
                    models.ForeignKey(
                        blank=True,
                        db_comment="Optional reference to the submitting user.",
                        help_text="The user who submitted this form, if authenticated.",
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        to=settings.AUTH_USER_MODEL,
                        verbose_name="Submitting User",
                    ),
                ),
            ],
            options={
                "verbose_name": "Form Submission",
                "verbose_name_plural": "Form Submissions",
                "db_table": "form_submissions",
                "ordering": ["-submitted_at"],
            },
        ),
        migrations.AddConstraint(
            model_name="fieldtype",
            constraint=models.UniqueConstraint(
                fields=("name",), name="unique_field_type_name"
            ),
        ),
        migrations.AddField(
            model_name="dynamicfield",
            name="field_type",
            field=models.ForeignKey(
                db_comment="References the field type definition.",
                help_text="The type of field (e.g., text, number, dropdown, etc.), linked to a FieldType entry.",
                on_delete=django.db.models.deletion.PROTECT,
                to="dynamic_form.fieldtype",
                verbose_name="Field Type",
            ),
        ),
        migrations.AddField(
            model_name="dynamicfield",
            name="form",
            field=models.ForeignKey(
                db_comment="A foreign key linking this field to its parent form.",
                help_text="The form to which this field belongs.",
                on_delete=django.db.models.deletion.CASCADE,
                related_name="fields",
                to="dynamic_form.dynamicform",
                verbose_name="Parent Form",
            ),
        ),
        migrations.AddIndex(
            model_name="formsubmission",
            index=models.Index(
                fields=["form", "submitted_at"], name="form_submis_form_id_01095c_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="formsubmission",
            index=models.Index(
                fields=["user", "submitted_at"], name="form_submis_user_id_05d63d_idx"
            ),
        ),
        migrations.AlterUniqueTogether(
            name="dynamicfield",
            unique_together={("form", "name")},
        ),
    ]
